"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAxiosInstance = void 0;
const axios_1 = __importDefault(require("axios"));
const interfaces_1 = require("../client/interfaces");
const constants_1 = require("./constants");
const helpers_1 = require("./helpers");
const createAxiosInstance = (config) => {
    const dataLanguage = (config === null || config === void 0 ? void 0 : config.dataLanguage) || interfaces_1.EResponseDataLanguage.ru;
    const dataFormat = (config === null || config === void 0 ? void 0 : config.dataFormat) || interfaces_1.EResponseDataFormat.json;
    const api = axios_1.default.create({
        baseURL: constants_1.API_BASE_URL,
        withCredentials: true,
        params: {
            lang: dataLanguage,
        },
    });
    const setDataFormat = (config) => {
        if (config.data != null && config.data.do_not_mutate_request) {
            return config;
        }
        return Object.assign(Object.assign({}, config), { url: `${config.url}.${dataFormat}` });
    };
    api.interceptors.request.use(setDataFormat);
    const onSuccess = (response) => {
        const error = (0, helpers_1.checkError)(response.data);
        response.issError = error;
        return response;
    };
    const onError = (err) => {
        console.error(err);
    };
    api.interceptors.response.use(onSuccess, onError);
    return api;
};
exports.createAxiosInstance = createAxiosInstance;
