"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("../api");
const analytics_1 = __importDefault(require("./analytics"));
const info_1 = __importDefault(require("./info"));
const security_1 = __importDefault(require("./security"));
class MoexClient {
    constructor(config) {
        this.request = (url, params) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (url.length == 0)
                throw new Error("url cannot be empty");
            if (params)
                for (const [k, v] of Object.entries((_a = this.api.defaults.params) !== null && _a !== void 0 ? _a : {}))
                    if (!params[k])
                        params[k] = v;
            return yield this.api.get(url, {
                params: params,
                data: {
                    do_not_mutate_request: url.indexOf("?") > -1 || url.indexOf(".") > -1,
                },
            });
        });
        this.api = (0, api_1.createAxiosInstance)(config);
        this.info = new info_1.default(this.api);
        this.analytics = new analytics_1.default(this.api);
        this.security = new security_1.default(this.api);
    }
}
/*-----------------------------------------------------------------*/
function newMoexClient(moexClientConstructor, config) {
    return new moexClientConstructor(config);
}
const createMoexCLient = (moexClient) => (config) => newMoexClient(moexClient, config);
/**
 * Базовые запросы к MOEX ISS API.
 * {@link http://iss.moex.com/iss/reference/ MOEX ISS}
 */
exports.default = createMoexCLient(MoexClient);
